<?php

// If we are outside SMF throw an error.
if (!defined('SMF'))
	die('Hacking attempt...');

// Add admin settings.
function affiliates_admin_area(&$admin_areas)
{
	global $txt;
	
	loadLanguage('Affiliates');
	
	$admin_areas['config']['areas']['affiliates'] = array(
		'label' => $txt['admin_affiliates'],
		'file' => 'AffiliatesAdmin.php',
		'function' => 'AffiliatesAdminMenu',
		'icon' => 'posts',
		'subsections' => array(
			'main' => array($txt['admin_affiliates']),
			'add_affiliate' => array($txt['add_affiliates']),
			'settings' => array($txt['settings']),
		),
	);
}

// Set up the permisisons.
function load_affiliates_permissions(&$permissionGroups, &$permissionList, &$leftPermissionGroups, &$hiddenPermissions, &$relabelPermissions)
{ 
    $permissionList['membergroup'] += array(
        'view_affiliates' => array(false, 'affiliates', 'affiliates'),
		'submit_affiliates' => array(false, 'affiliates', 'affiliates'),
		'manage_affiliates' => array(false, 'affiliates', 'affiliates'),
    );
}

// Permisisons that we do not want guests to have.
function load_no_guests_affiliates_permissions()
{
	global $context;

	$context['non_guest_permissions'] = array_merge(
		$context['non_guest_permissions'],
		array(
		    'submit_affiliates',
		    'manage_affiliates',
		)
	);
}

//Action Jackson right here lol :D.
function affiliates_actions(&$actionArray)
{
	$actionArray['affiliates'] = array('Subs-Affiliates.php', 'AffiliatesMenu');
	$actionArray['myaffiliates'] = array('Subs-MyAffiliates.php', 'MyAffiliates');
}

//Add the affiliates button at the navigation.
function affiliates_menu_button(&$menu_buttons)
{
	global $sourcedir, $modSettings, $scripturl, $txt;
	
	loadLanguage('Affiliates');
	
	$affiliates = array(
		'affiliates' => array(
			'title' => $txt['admin_affiliates'],
			'href' => $scripturl . '?action=affiliates',
			'show' => allowedTo('view_affiliates'),
			'icon' => 'posts',
			'sub_buttons' => array(
			    'affiliates' => array(
					'title' => $txt['view_affiliates'],
					'href' => $scripturl . '?action=affiliates',
					'show' => allowedTo('view_affiliates'),
				),
				'addaffiliates' => array(
					'title' => $txt['add_affiliates'],
					'href' => $scripturl . '?action=affiliates;sa=addaffiliates',
					'show' => allowedTo('submit_affiliates'),
				),
				'myaffiliates' => array(
					'title' => $txt['my_affiliates_page'],
					'href' => $scripturl . '?action=myaffiliates',
					'show' => allowedTo('submit_affiliates'),
				),
			),
		),
	);	
	
	$position = array_search('login', array_keys($menu_buttons));

	if($position === false) 
	{
		$menu_buttons = array_merge($menu_buttons, $affiliates);
	}
	else 
	{
		$menu_buttons = array_merge(
			array_slice($menu_buttons, 0, $position),
			$affiliates,
			array_slice($menu_buttons, $position)
		);
	}
}

// Display affiliate count on members postbits.
function load_count_context(&$data, $user)
{
	global $user_profile, $modSettings, $txt, $topic;
		
	loadLanguage('Affiliates');

	$data['affiliate_count'] = $user_profile[$user]['affiliate_count'];

	if (!empty($modSettings['enable_affiliate_count_members_posts']) && !empty($topic))
	{
		$data['custom_fields']['affiliate_count'] = array(
			'title' => $txt['total_affiliate_count'],
			'col_name' => 'affiliate_count',
			'value' => $user_profile[$user]['affiliate_count'],
			'placement' => 0,
		);
	}
}

// Display affiliate count on members profiles.
function load_count_data(&$columns, &$tables, &$set)
{
	switch ($set)
	{
		case 'normal':
			$columns .= ', mem.affiliate_count';
			break;
		case 'profile':
			$columns .= ', mem.affiliate_count';
			break;
		case 'minimal':
			$columns .= ', mem.affiliate_count';
			break;
		default:
			trigger_error('loadMemberData(): Invalid member data set \'' . $set . '\'', E_USER_WARNING);
	}
}

// Load custom profile fields.
function load_custom_fields($user, $area)
{
	loadLanguage('Affiliates');

	if ($area == 'summary')
		AffiliateCountProfile();
}

//Insert the affiliate count on members profiles.
function AffiliateCountProfile()
{
	global $context, $txt, $modSettings, $scripturl;

	if (!empty($modSettings['enable_affiliate_count_members_profiles']))
	    $context['custom_fields']['affiliate_count'] = array(
		   'name' => $txt['total_affiliate_count'],
		   'colname' => 'affiliate_count',
		   'output_html' => $context['member']['affiliate_count'],
		   'placement' => 0,
	    );

}

// Affiliates menu
function AffiliatesMenu()
{
	global $context, $txt, $scripturl;
	
	if(!allowedTo('view_affiliates'))
		fatal_lang_error('no_access', false);

	$context['page_title'] = $txt['admin_affiliates'];
	
	$context['linktree'][] = array(
		'url' => $scripturl . '?action=affiliates',
		'name' => $txt['admin_affiliates'],
	);

	$subActions = array(
		'affiliates' => 'AffiliatesPage',
		'addaffiliates' => 'AddAffiliates',
		'submitaffiliates' => 'SubmitAffiliates',
		'edit' => 'EditAffiliates',
		'update' => 'UpdateAffiliates',
		'view' => 'ViewAffiliates',
	);

    // Call the right function for this sub-acton.
	if (!isset($_REQUEST['sa']) || !isset($subActions[$_REQUEST['sa']]))
		$sub_action = 'affiliates';
	else
		$sub_action = $_REQUEST['sa'];

	$subActions[$sub_action]();
}

// Display add affiliate form.
function AddAffiliates()
{
	global $context, $txt, $scripturl;
	
	if(!allowedTo('submit_affiliates'))
		fatal_lang_error('no_access', false);
	
	loadTemplate('Affiliates');
	
	$context['page_title'] = $txt['add_affiliates'];
	$context['sub_template'] = 'add_affiliates_front';
	
	$context['linktree'][] = array(
		'url' => $scripturl . '?action=affiliates;sa=addaffiliates',
		'name' => $txt['add_affiliates'],
	);
	
	DailyAffiliatesLimit();
}

// Insert affiliate in the database.
function SubmitAffiliates()
{
	global $smcFunc, $user_info, $scripturl;
	
	$_POST['add_affiliate_image'] = $smcFunc['htmlspecialchars']($_POST['add_affiliate_image']);
	$_POST['add_affiliate_link'] = $smcFunc['htmlspecialchars']($_POST['add_affiliate_link']);
	$_POST['add_affiliate_description'] = $smcFunc['htmlspecialchars']($_POST['add_affiliate_description']);
	
	censorText($_POST['add_affiliate_description']);
	
	$image = !empty($_POST['add_affiliate_image']) ? $_POST['add_affiliate_image'] : '';
	$link = !empty($_POST['add_affiliate_link']) ? $_POST['add_affiliate_link'] : '';
	$description = !empty($_POST['add_affiliate_description']) ? $_POST['add_affiliate_description'] : '';
	
	if (empty($image))
		fatal_lang_error('you must_enter_image_url', false);
	
	$smcFunc['db_insert']('',
		'{db_prefix}affiliates',
		array(
			  'user_id' => 'int', 'image' => 'string', 'link' => 'string', 'description' => 'string', 'time' => 'int',
		    ),
		array(
			  $user_info['id'], $image, $link, $description, time(),
			),
		array('id')
	);
	
	$smcFunc['db_query']('', '
		UPDATE {db_prefix}members
		SET affiliate_count = affiliate_count + 1
	    WHERE id_member = {int:member}',
		array(
			'member' => $user_info['id'],
		)
	);
		
	redirectexit($scripturl . '?action=affiliates');
}

// Display edit affiliate form.
function EditAffiliates()
{
	global $smcFunc, $context, $txt, $scripturl;
	
	$id = (int) $_REQUEST['id'];
	
	if(empty($id))
		fatal_lang_error('affiliate_is_deleted', false);

	loadTemplate('Affiliates');
	
	$context['page_title'] = $txt['editing_affiliate'] . $id;
	$context['sub_template'] = 'edit_affiliates_front';
	
	$context['linktree'][] = array(
		'url' => $scripturl . '?action=affiliates;sa=edit;id=' . $id,
		'name' => $txt['editing_affiliate'] . $id,
	);
	
	$results = $smcFunc['db_query']('', '
	        SELECT id, image, link, description, user_id
	        FROM {db_prefix}affiliates
	        WHERE id = {int:id} 
		    LIMIT 1',
		    array(
			   'id' => $id,
		    )
	    );

    $row = $smcFunc['db_fetch_assoc']($results);
	$smcFunc['db_free_result']($results);
	
	$context['aff_edit'] = $row;
	
	if ($context['user']['id'] != $context['aff_edit']['user_id'] && !allowedTo('manage_affiliates'))
		fatal_lang_error('no_access', false);
}

// Insert updated affiliate in the database.
function UpdateAffiliates()
{
	global $smcFunc, $scripturl;
	
	$id = (int) $_REQUEST['id'];
	
	if(empty($id))
		fatal_lang_error('affiliate_is_deleted', false);
	
	$image = $smcFunc['htmlspecialchars']($_POST['add_affiliate_image']);
	$link = $smcFunc['htmlspecialchars']($_POST['add_affiliate_link']);
	$description = $smcFunc['htmlspecialchars']($_POST['add_affiliate_description']);
	
	censorText($description);
	
	if (empty($image))
		fatal_lang_error('you must_enter_image_url', false);
	
	$smcFunc['db_query']('',"
			UPDATE {db_prefix}affiliates
			SET
				image = {string:image},
				link = {string:link},			
				description = {string:description}							
			WHERE id = {int:id}",
			array(
			    'id' => $id,
				'image' => $image,
				'link' => $link,	
				'description' => $description,				
			)
	);
		
	redirectexit($scripturl . '?action=affiliates');
}

// Display affiliates.
function AffiliatesPage()
{
	global $txt, $sourcedir, $scripturl, $context, $smcFunc;
	
	// User pressed the 'remove selection button'.
	if (allowedTo('manage_affiliates') && !empty($_POST['delete']) && !empty($_POST['remove']) && is_array($_POST['remove']))
	{
		checkSession();

		foreach ($_POST['remove'] as $index => $log_time)
			$_POST['remove'][(int) $index] = (int) $log_time;

		$smcFunc['db_query']('', '
			DELETE FROM {db_prefix}affiliates
			WHERE id IN ({array_int:affiliates_list})',
			array(
				'affiliates_list' => $_POST['remove'],
			)
		);

		redirectexit($scripturl . '?action=affiliates');
	}
	
	$listOptions = array(
		'id' => 'affiliates_list',
		'items_per_page' => 20,
		'base_href' => $scripturl . '?action=affiliates',
		'default_sort_col' => 'image',
		'no_items_label' => $txt['no_affiliates_added_yet'],
		'get_items' => array(
			'function' => 'list_getAffiliates',
		),
		'get_count' => array(
			'function' => 'list_countAffiliates',
		),
		'columns' => array(
			'image' => array(
				'header' => array(
					'value' => $txt['image'],
					'style' => 'width: 10%; text-align:center',
				),
				'data' => array(
					'db' => 'image',
				),
				'sort' =>  array(
					'default' => 'image',
					'reverse' => 'image DESC',
				),
			),
			'description' => array(
				'header' => array(
					'value' => $txt['description'],
				),
				'data' => array(
					'db' => 'description',
					'style' => 'width: 45%; text-align: center;',
				),
				'sort' =>  array(
					'default' => 'description',
					'reverse' => 'description DESC',
				),
			),
			'views' => array(
				'header' => array(
					'value' => $txt['views'],
				),
				'data' => array(
					'db' => 'views',
					'style' => 'width: 5%; text-align: center;',
				),
				'sort' =>  array(
					'default' => 'views',
					'reverse' => 'views DESC',
				),
			),
			'user_id' => array(
				'header' => array(
					'value' => $txt['username'],
				),
				'data' => array(
					'db' => 'user_id',
					'style' => 'width: 15%; text-align: center;',
				),
				'sort' =>  array(
					'default' => 'user_id',
					'reverse' => 'user_id DESC',
				),
			),
			'time' => array(
				'header' => array(
					'value' => $txt['affiliate_time'],
				),
				'data' => array(
					'db' => 'time',
					'style' => 'width: 25%; text-align: center;',
				),
				'sort' =>  array(
					'default' => 'time',
					'reverse' => 'time DESC',
				),
			),
			'modify' => array(
				'header' => array(
					'value' => allowedTo('manage_affiliates') ? $txt['modify'] : '',
					'style' => 'width: 5%; text-align: center;',
				),
				'data' => array(
					'sprintf' => array(
						'format' => allowedTo('manage_affiliates') ? '<a href="' . $scripturl . '?action=affiliates;sa=edit;id=%1$d">' . $txt['edit'] . '</a>' : '',
						'params' => array(
							'id' => false,
						),
					),
					'class' => 'centercol',
				),
			),
			'check' => array(
				'header' => array(
					'value' => allowedTo('manage_affiliates') ? '<input type="checkbox" onclick="invertAll(this, this.form);" class="input_check" />' : '',
			),
			'data' => array(
					'sprintf' => array(
						'format' => allowedTo('manage_affiliates') ? '<input type="checkbox" name="remove[]" value="%1$d" class="input_check" />' : '',
						'params' => array(
							'id' => false,
						),
					),
					'style' => 'text-align: center',
				),
			),
		),	
		'form' => array(
			'href' => $scripturl . '?action=affiliates',
		),
		'additional_rows' => array(
			array(
				'position' => 'below_table_data',
				'value' => allowedTo('manage_affiliates') ? '<input type="submit" name="delete" value="' . $txt['delete_selected_affiliates'] . '" onclick="return confirm(\'' . $txt['confirm_delete_selected_affiliates_desc'] . '\');" class="button_submit" />' : '',
				'style' => 'text-align: right;',
			),
		),
	);
		

	require_once($sourcedir . '/Subs-List.php');
	createList($listOptions);

	$context['sub_template'] = 'show_list';
	$context['default_list'] = 'affiliates_list';
}

// Get all added affiliates.
function list_getAffiliates($start, $items_per_page, $sort)
{
	global $smcFunc, $scripturl, $txt;
	
	$result = $smcFunc['db_query']('', '
	       SELECT aff.id, aff.user_id, aff.image, aff.link, aff.description, aff.views, aff.time,
		   mem.id_member, mem.member_name
		   FROM {db_prefix}affiliates AS aff
		   LEFT JOIN {db_prefix}members AS mem ON (mem.id_member = aff.user_id)
		   ORDER BY {raw:sort}
		   LIMIT {int:start}, {int:per_page}',
		   array(
				 'sort' => $sort,
		         'start' => $start,
			     'per_page' => $items_per_page,
			    )
	);
	
    $affiliates = array();
	
	while ($row = $smcFunc['db_fetch_assoc']($result))
	{
		$affiliates[] = array(
		    'id' => $row['id'],
			'user_id' => !empty($row['user_id']) ? '<a href="' . $scripturl . '?action=profile;u=' . $row['user_id'] . '">' . $row['member_name'] . '</a>' : $txt['guest'],
			'image' => '<a href="' . $scripturl . '?action=affiliates;sa=view;id='.$row['id']. '"><img src="'.$row['image'].'" alt="" /></a>',
			'description' => !empty($row['description']) ? parse_bbc($row['description']) : $txt['no_description_added'],
			'views' => $row['views'],
			'time' => timeformat($row['time']),
		);
	}
	
	return $affiliates;

	$smcFunc['db_free_result']($result);
}

// Count all added affiliates for the pagination.
function list_countAffiliates()
{
	global $smcFunc;
	
	$result = $smcFunc['db_query']('', '
		SELECT COUNT(*)
		FROM {db_prefix}affiliates',
		array( )
	);
				
	list ($affiliates) = $smcFunc['db_fetch_row']($result);
	
	$smcFunc['db_free_result']($result);

	return $affiliates;
}

// Load affiliates template.
function affiliates_load_theme()
{
	global $context, $settings, $board, $modSettings;
	
	loadTemplate('Affiliates');
	loadLanguage('Affiliates');
	
	$context['template_layers'][] = 'affiliates_tpl';
		 
	if (!empty($modSettings['display_affiliates_forum']) && allowedTo('view_affiliates') && empty($_GET['xml']) && empty($_GET['action']) && empty($_GET['topic']) && empty($_GET['board']))
	{
		displayAffiliatesBoard();

		if (!empty($context['affiliatesList']))
		{
			$context['html_headers'] .= '<link rel="stylesheet" type="text/css" href="'.$settings['default_theme_url'].'/css/Affiliates.css" />';
		}
		
	}
}

// Display all affiliates on board index.
function displayAffiliatesBoard()
{
	global $smcFunc, $context;

    $affiliates = $smcFunc['db_query']('', '
	       SELECT * FROM {db_prefix}affiliates
		   ORDER BY RAND()
		   LIMIT 1',
		   array()
	);
	
	$context['affiliatesList'] = array();

	while ($row = $smcFunc['db_fetch_assoc']($affiliates))
	{
		$context['affiliatesList'][$row['id']] = array(
			'id' => $row['id'],
			'image' => !empty($row['image']) ? $row['image'] : '',
			'description' => !empty($row['description']) ? parse_bbc($row['description']) : '',
		);
	}

	$smcFunc['db_free_result']($affiliates);			
}

// View affiliate.
function ViewAffiliates()
{
    global $smcFunc, $context, $scripturl, $txt;
	
	$id = (int) $_REQUEST['id'];
	
	if(empty($id))
		fatal_lang_error('affiliate_is_deleted', false);
	
	if(!allowedTo('view_affiliates'))
		fatal_lang_error('no_access', false);
	
	loadLanguage('Affiliates');
    loadTemplate('Affiliates');
	
	$context['sub_template'] = 'view_affiliate';
	$context['page_title'] = $txt['viewing_affiliate'] . $id;
	
	$context['linktree'][] = array(
		'url' => $scripturl . '?action=affiliates;sa=view;id=' . $id,
		'name' => $txt['viewing_affiliate'] . $id,
	);
 
	$result = $smcFunc['db_query']('', '
		SELECT aff.id, aff.user_id, aff.image, aff.link, aff.description, aff.views, aff.time,
		mem.id_member, mem.member_name
		FROM {db_prefix}affiliates AS aff
		LEFT JOIN {db_prefix}members AS mem ON (mem.id_member = aff.user_id)
		WHERE aff.id = {int:id}',
        array(
		        'id' => $id,
		     )
	    );
		
	$context['affdata'] = array();
	
	while ($row = $smcFunc['db_fetch_assoc']($result))
	{	
		$context['affdata'][$row['id']] = array(
		    'id' => $row['id'],
		    'user_id' => !empty($row['user_id']) ? '<a href="' . $scripturl . '?action=profile;u=' . $row['user_id'] . '">' . $row['member_name'] . '</a>' : $txt['guest'],
			'link' => !empty($row['link']) ? '<a href="'.$row['link'].'" target="_blank">'.$row['link'].'</a>' : $txt['no_link_added'],
			'image' => $row['image'],
			'description' => !empty($row['description']) ? parse_bbc($row['description']) : $txt['no_description_added'],
			'views' => $row['views'],
			'time' => timeformat($row['time']),
	    );
	}
	
	$smcFunc['db_free_result']($result);
	
	UpdateAffiliateViews();
}

// Update sffiliate views.
function UpdateAffiliateViews()
{
    global $smcFunc, $user_info;
	
	$id = (int) $_REQUEST['id'];
	
	if(empty($id))
		fatal_lang_error('affiliate_is_deleted', false);
	
	$results = $smcFunc['db_query']('', '
		SELECT user_id
		FROM {db_prefix}affiliates
		WHERE id = {int:id} 
		LIMIT 1',
		array(
			'id' => $id,
		)
	);
	
	list ($owner) = $smcFunc['db_fetch_row']($results);
	$smcFunc['db_free_result']($results);
	
	if ($owner != $user_info['id'])
	{
	    $smcFunc['db_query']('', '
		    UPDATE {db_prefix}affiliates
		    SET views = views + 1
		    WHERE id = {int:id}',
		    array(
			    'id' => $id,
		    )
	    );
	}
}

//Daily affiliates limit.
function DailyAffiliatesLimit()
{
   global $smcFunc, $modSettings, $user_info;
   
   loadLanguage('Affiliates');
   
    if (!empty($modSettings['daily_affiliates_limit']))
    {
	    $modSettings['daily_affiliates_nummber'] = !empty($modSettings['daily_affiliates_nummber']) ? (int) $modSettings['daily_affiliates_nummber'] : 0 ; 
	    
	    $excluded_groups = !empty($modSettings['daily_excluded_groups']) ? explode(",", $modSettings['daily_excluded_groups']) : array();
		
	    $todays_affiliates = $smcFunc['db_query']('', '
	        SELECT COUNT(id) as daily_affiliates
	        FROM {db_prefix}affiliates
	        WHERE user_id = {int:submiter}
	        AND time > {int:time}',
	        array(
			      'submiter' => $user_info['id'],
			      'time' => time() - 86400
		   )
	    );
	
	    list ($daily_affiliates) = $smcFunc['db_fetch_row']($todays_affiliates);
		
	    $smcFunc['db_free_result']($todays_affiliates);
	
	    if(!empty($modSettings['daily_affiliates_nummber']) && $daily_affiliates >= $modSettings['daily_affiliates_nummber'] && !$user_info['is_admin'] && count(array_intersect($user_info['groups'], $excluded_groups)) == 0)
        {
            fatal_lang_error('daily_error_message', false, array($modSettings['daily_affiliates_nummber']));
        }
    }
}